package com.ygtx.gxt.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ygtx.gxt.mapper.GxtScoreRuntimeMapper;
import com.ygtx.gxt.domain.GxtScoreRuntime;
import com.ygtx.gxt.service.IGxtScoreRuntimeService;

/**
 * 运行时长分值配置Service业务层处理
 * 
 * @author ygtx
 * @date 2025-11-11
 */
@Service
public class GxtScoreRuntimeServiceImpl implements IGxtScoreRuntimeService
{
    @Autowired
    private GxtScoreRuntimeMapper gxtScoreRuntimeMapper;

    /**
     * 查询运行时长分值配置
     * 
     * @param id 运行时长分值配置主键
     * @return 运行时长分值配置
     */
    @Override
    public GxtScoreRuntime selectGxtScoreRuntimeById(Long id)
    {
        return gxtScoreRuntimeMapper.selectGxtScoreRuntimeById(id);
    }

    /**
     * 查询运行时长分值配置列表
     * 
     * @param gxtScoreRuntime 运行时长分值配置
     * @return 运行时长分值配置
     */
    @Override
    public List<GxtScoreRuntime> selectGxtScoreRuntimeList(GxtScoreRuntime gxtScoreRuntime)
    {
        return gxtScoreRuntimeMapper.selectGxtScoreRuntimeList(gxtScoreRuntime);
    }

    /**
     * 新增运行时长分值配置
     * 
     * @param gxtScoreRuntime 运行时长分值配置
     * @return 结果
     */
    @Override
    public int insertGxtScoreRuntime(GxtScoreRuntime gxtScoreRuntime)
    {
        return gxtScoreRuntimeMapper.insertGxtScoreRuntime(gxtScoreRuntime);
    }

    /**
     * 修改运行时长分值配置
     * 
     * @param gxtScoreRuntime 运行时长分值配置
     * @return 结果
     */
    @Override
    public int updateGxtScoreRuntime(GxtScoreRuntime gxtScoreRuntime)
    {
        return gxtScoreRuntimeMapper.updateGxtScoreRuntime(gxtScoreRuntime);
    }

    /**
     * 批量删除运行时长分值配置
     * 
     * @param ids 需要删除的运行时长分值配置主键
     * @return 结果
     */
    @Override
    public int deleteGxtScoreRuntimeByIds(Long[] ids)
    {
        return gxtScoreRuntimeMapper.deleteGxtScoreRuntimeByIds(ids);
    }

    /**
     * 删除运行时长分值配置信息
     * 
     * @param id 运行时长分值配置主键
     * @return 结果
     */
    @Override
    public int deleteGxtScoreRuntimeById(Long id)
    {
        return gxtScoreRuntimeMapper.deleteGxtScoreRuntimeById(id);
    }
}